@@ -1,6 +1,6 @@
 #-----------------------------------------------------------------------------
 #
-#	$Id : OODoc.pm 1.202 2004-07-30 JMG$
+#	$Id : OODoc.pm 1.203 2004-08-03 JMG$
 #
 #	Initial developer: Jean-Marie Gouarne
 #	Copyright 2004 by Genicorp, S.A. (www.genicorp.com)
@@ -11,16 +11,16 @@
 #
 #-----------------------------------------------------------------------------
 
-use OpenOffice::OODoc::File		1.105;
-use OpenOffice::OODoc::Meta		1.004;
-use OpenOffice::OODoc::Document		1.007;
-use OpenOffice::OODoc::Manifest		1.001;
+use OpenOffice::OODoc::File		1.106;
+use OpenOffice::OODoc::Meta		1.005;
+use OpenOffice::OODoc::Document		1.008;
+use OpenOffice::OODoc::Manifest		1.002;
 
 #-----------------------------------------------------------------------------
 
 package	OpenOffice::OODoc;
 use 5.008_000;
-our $VERSION				= 1.202;
+our $VERSION				= 1.203;
 
 require Exporter;
 our @ISA    = qw(Exporter);
@@ -45,7 +45,7 @@ sub	ooReadConfig
 		}
 	unless ($filename)
 		{
-		warn	"[" . __PACKAGE__ . "::readConfig] "	.
+		warn	"[" . __PACKAGE__ . "::ooReadConfig] "	.
 			"Missing configuration file\n";
 		return undef;
 		}
@@ -55,7 +55,7 @@ sub	ooReadConfig
 			);
 	unless ($config)
 		{
-		warn	"[" . __PACKAGE__ . "::readConfig] "	.
+		warn	"[" . __PACKAGE__ . "::ooReadConfig] "	.
 			"Syntax error in configuration file $filename\n";
 		return undef;
 		}
@@ -137,7 +137,7 @@ sub	ooLocalEncoding
 		    }
 		else
 		    {
-		    warn	"[" . __PACKAGE__ . "::localEncoding] " .
+		    warn	"[" . __PACKAGE__ . "::ooLocalEncoding] " .
 				"Unsupported encoding\n";
 		    }
 		}
